Struct parsec_interface::operations::psa_aead_encrypt::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub alg: Aead,
pub nonce: Zeroizing<Vec<u8>>,
pub additional_data: Zeroizing<Vec<u8>>,
pub plaintext: Zeroizing<Vec<u8>>,
}Expand description
Native object for AEAD encryption operations.
Fields
key_name: StringDefines which key should be used for the encryption operation.
alg: AeadAn AEAD encryption algorithm that is compatible with the key type.
nonce: Zeroizing<Vec<u8>>Nonce or IV to use.
additional_data: Zeroizing<Vec<u8>>Additional data that will be authenticated but not encrypted.
plaintext: Zeroizing<Vec<u8>>Data that will be authenticated and encrypted.
Implementations
Validate the contents of the operation against the attributes of the key it targets
This method checks that:
- the key policy allows encrypting messages
- the key policy allows the encryption algorithm requested in the operation
- the key type is compatible with the requested algorithm
- the message to encrypt is valid (not length 0)
- the nonce is valid (not length 0)