Struct parsec_interface::operations::psa_aead_encrypt::Result [−][src]
Native object for AEAD encrypt result.
Fields
ciphertext: Zeroizing<Vec<u8>>The ciphertext field contains the encrypted and authenticated data.For algorithms where
the encrypted data and the authentication tag are defined as separate outputs, the authentication
tag is appended to the encrypted data.