Algorithm

Enum Algorithm 

pub enum Algorithm {
    None,
    Hash(Hash),
    Mac(Mac),
    Cipher(Cipher),
    Aead(Aead),
    AsymmetricSignature(AsymmetricSignature),
    AsymmetricEncryption(AsymmetricEncryption),
    KeyAgreement(KeyAgreement),
    KeyDerivation(KeyDerivation),
}
Enumeration of possible algorithm definitions. Each variant of the enum contains a main algorithm type (which is required for that variant).

Variants



None

An invalid algorithm identifier value. None does not allow any cryptographic operation with the key. The key can still be used for non-cryptographic actions such as exporting, if permitted by the usage flags.



Hash(Hash)

Hash algorithm.



Mac(Mac)

MAC algorithm.



Cipher(Cipher)

Symmetric Cipher algorithm.



Aead(Aead)

Authenticated Encryption with Associated Data (AEAD) algorithm.



AsymmetricSignature(AsymmetricSignature)

Public-key signature algorithm.



AsymmetricEncryption(AsymmetricEncryption)

Public-key encryption algorithm.



KeyAgreement(KeyAgreement)

Key agreement algorithm.



KeyDerivation(KeyDerivation)

Key derivation algorithm.

Implementations

Source

impl Algorithm

pub fn is_hmac(self) -> bool

Check if the algorithm is a HMAC algorithm, truncated or not

Example
use psa_crypto::types::algorithm::{Algorithm, Mac, FullLengthMac, Hash};
let hmac = Algorithm::Mac(Mac::Truncated {
    mac_alg: FullLengthMac::Hmac { hash_alg: Hash::Sha256 },
    mac_length: 30,
});
assert!(hmac.is_hmac());