AsymmetricSignature

Enum AsymmetricSignature 

pub enum AsymmetricSignature {
    RsaPkcs1v15Sign {
        hash_alg: SignHash,
    },
    RsaPkcs1v15SignRaw,
    RsaPss {
        hash_alg: SignHash,
    },
    Ecdsa {
        hash_alg: SignHash,
    },
    EcdsaAny,
    DeterministicEcdsa {
        hash_alg: SignHash,
    },
}
Enumeration of asymmetric signing algorithms supported.

Variants



RsaPkcs1v15Sign

RSA PKCS#1 v1.5 signature with hashing.

Fields

hash_alg: SignHash

A hash algorithm to use.



RsaPkcs1v15SignRaw

Raw PKCS#1 v1.5 signature.



RsaPss

RSA PSS signature with hashing.

Fields

hash_alg: SignHash

A hash algorithm to use.



Ecdsa

ECDSA signature with hashing.

Fields

hash_alg: SignHash

A hash algorithm to use.



EcdsaAny

ECDSA signature without hashing.



DeterministicEcdsa

Deterministic ECDSA signature with hashing.

Fields

hash_alg: SignHash

A hash algorithm to use.

Implementations

Source

impl AsymmetricSignature

pub fn is_alg_permitted(self, alg: AsymmetricSignature) -> bool

Check if the alg given for a cryptographic operation is permitted to be used with this algorithm as a policy

Example
use psa_crypto::types::algorithm::{AsymmetricSignature, SignHash, Hash};
assert!(AsymmetricSignature::RsaPkcs1v15Sign { hash_alg: SignHash::Any }
        .is_alg_permitted(AsymmetricSignature::RsaPkcs1v15Sign {
            hash_alg:  SignHash::Specific(Hash::Sha1)
        })
       );
assert!(!AsymmetricSignature::RsaPkcs1v15Sign { hash_alg: SignHash::Specific(Hash::Sha256) }
        .is_alg_permitted(AsymmetricSignature::RsaPkcs1v15Sign {
            hash_alg:  SignHash::Specific(Hash::Sha1)
        })
       );
pub fn is_rsa_alg(self) -> bool

Check if this is a RSA algorithm

pub fn is_ecc_alg(self) -> bool

Check if this is an ECC algorithm

pub fn is_hash_len_permitted(self, hash_len: usize) -> bool

Determines if the given hash length is compatible with the asymmetric signature scheme

pub fn hash(self) -> Option<SignHash>

Retrieves the specific hash that the AsymmetricSignature algorithm is restricted to.

For algorithms that do not specify a hash, None is returned.