Cipher

Enum Cipher 

pub enum Cipher {
    StreamCipher,
    Ctr,
    Cfb,
    Ofb,
    Xts,
    EcbNoPadding,
    CbcNoPadding,
    CbcPkcs7,
}
Enumeration of symmetric encryption algorithms supported.

Variants



StreamCipher

The stream cipher mode of a stream cipher algorithm.



Ctr

A stream cipher built using the Counter (CTR) mode of a block cipher.



Cfb

A stream cipher built using the Cipher Feedback (CFB) mode of a block cipher.



Ofb

A stream cipher built using the Output Feedback (OFB) mode of a block cipher.



Xts

The XTS cipher mode of a block cipher.



EcbNoPadding

The Electronic Code Book (ECB) mode of a block cipher, with no padding.



CbcNoPadding

The Cipher Block Chaining (CBC) mode of a block cipher, with no padding.



CbcPkcs7

The Cipher Block Chaining (CBC) mode of a block cipher, with PKCS#7 padding.

Implementations

Source

impl Cipher

pub fn is_block_cipher_mode(self) -> bool

Check is the cipher algorithm is a mode of a block cipher.