Struct parsec_interface::operations::psa_asymmetric_decrypt::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub alg: AsymmetricEncryption,
pub ciphertext: Zeroizing<Vec<u8>>,
pub salt: Option<Zeroizing<Vec<u8>>>,
}Expand description
Native object for asymmetric decryption operations.
Fields
key_name: StringDefines which key should be used for the signing operation.
alg: AsymmetricEncryptionAn asymmetric encryption algorithm to be used for decryption, that is compatible with the type of key.
ciphertext: Zeroizing<Vec<u8>>The short encrypted message to be decrypted.
salt: Option<Zeroizing<Vec<u8>>>Salt to use during decryption, if supported by the algorithm.
Implementations
Validate the contents of the operation against the attributes of the key it targets
This method checks that:
- the key policy allows decrypting messages
- the key policy allows the decryption algorithm requested in the operation
- the key type is compatible with the requested algorithm
- if the algorithm is RsaPkcs1v15Crypt, it has no salt (it is not compatible with salt)
- the message to decrypt is valid (not length 0)