Struct parsec_interface::operations::psa_export_key::Result [−][src]
Native object for result of key export operation.
Fields
data: Secret<Vec<u8>>data holds the bytes defining the key, formatted as specified
by the provider for which the request was made.