Struct parsec_interface::operations::psa_export_public_key::Result [−][src]
Native object for result of public key export operation.
Fields
data: Zeroizing<Vec<u8>>data holds the bytes defining the public key, formatted as specified
by the provider for which the request was made.