Struct parsec_interface::operations::psa_generate_key::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub attributes: Attributes,
}Expand description
Native object for creating a cryptographic key.
Fields
key_name: Stringkey_name specifies a name by which the service will identify the key. Key
name must be unique per application.
attributes: Attributesattributes specifies the parameters to be associated with the key.