Struct parsec_interface::operations::psa_import_key::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub attributes: Attributes,
pub data: Secret<Vec<u8>>,
}Expand description
Native object for cryptographic key importing operation.
Fields
key_name: Stringkey_name specifies a name by which the service will identify the key. Key
name must be unique per application.
attributes: Attributesattributes specifies the attributes for the new key.
data: Secret<Vec<u8>>data contains the bytes for the key,
formatted in accordance with the requirements of the provider for the key type
specified in attributes.