Struct parsec_interface::operations::psa_import_key::Result [−][src]
pub struct Result;
Native object for the result of a cryptographic key import operation.
The true result is sent in the status field of the response header.