Struct parsec_interface::operations::psa_sign_hash::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub alg: AsymmetricSignature,
pub hash: Zeroizing<Vec<u8>>,
}Expand description
Native object for asymmetric sign operations.
Fields
key_name: StringDefines which key should be used for the signing operation.
alg: AsymmetricSignatureAn asymmetric signature algorithm that separates the hash and sign operations, that is compatible with the type of key.
hash: Zeroizing<Vec<u8>>The input whose signature is to be verified. This is usually the hash of a message.
Implementations
Validate the contents of the operation against the attributes of the key it targets
This method checks that:
- the key policy allows signing hashes
- the key policy allows the signing algorithm requested in the operation
- the key type is compatible with the requested algorithm
- the length of the given digest is consistent with the specified signing algorithm