Struct parsec_interface::operations::psa_sign_message::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub alg: AsymmetricSignature,
pub message: Zeroizing<Vec<u8>>,
}Expand description
Native object for asymmetric sign operations.
Fields
key_name: StringDefines which key should be used for the signing operation.
alg: AsymmetricSignatureAn asymmetric signature algorithm that separates the hash and sign operations, that is compatible with the type of key.
message: Zeroizing<Vec<u8>>The message to sign.
Implementations
Validate the contents of the operation against the attributes of the key it targets
This method checks that:
- the key policy allows signing messages
- the key policy allows the signing algorithm requested in the operation
- the key type is compatible with the requested algorithm