Struct parsec_interface::operations::psa_sign_message::Result [−][src]
Native object for asymmetric sign result.
Fields
signature: Zeroizing<Vec<u8>>The signature field contains the resulting bytes from the signing operation. The format of
the signature is as specified by the provider doing the signing.