Struct parsec_interface::operations::psa_verify_hash::Operation [−][src]
pub struct Operation {
pub key_name: String,
pub alg: AsymmetricSignature,
pub hash: Zeroizing<Vec<u8>>,
pub signature: Zeroizing<Vec<u8>>,
}Expand description
Native object for asymmetric verification of signatures.
Fields
key_name: Stringkey_name specifies the key to be used for verification.
alg: AsymmetricSignatureAn asymmetric signature algorithm that separates the hash and sign operations, that is compatible with the type of key.
hash: Zeroizing<Vec<u8>>The hash contains a short message or hash value as described for the
asymmetric signing operation.
signature: Zeroizing<Vec<u8>>Buffer containing the signature to verify.
Implementations
Validate the contents of the operation against the attributes of the key it targets
This method checks that:
- the key policy allows verifying signatures on hashes
- the key policy allows the verification algorithm requested in the operation
- the key type is compatible with the requested algorithm
- the length of the given digest is consistent with the specified verification algorithm