CheckDeprecated

Trait CheckDeprecated 

pub trait CheckDeprecated {
    // Required method
    fn check_deprecated(&self) -> Result<()>;
}
Checks if any part of the key template is deprecated by PSA Crypto API

Required Methods

fn check_deprecated(&self) -> Result<()>

Return Error with status ResponseStatus::DeprecatedPrimitive if any part of the key template is deprecated by PSA Crypto API

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl CheckDeprecated for parsec_interface::operations::psa_import_key::Operation

Source

impl CheckDeprecated for parsec_interface::operations::psa_generate_key::Operation