Enum parsec_interface::requests::Opcode [−][src]
Listing of available operations and their associated opcode.
Passed in headers as opcode. Check the
Operations
page of the book for more information.
Variants
Ping operation
PsaGenerateKey operation
PsaDestroyKey operation
PsaSignHash operation
PsaVerifyHash operation
PsaImportKey operation
PsaExportPublicKey operation
ListProviders operation
ListOpcodes operation
PsaAsymmetricEncrypt operation
PsaAsymmetricDecrypt operation
PsaExportKey operation
PsaGenerateRandom operation
ListAuthenticators operation
PsaHashCompute operation
PsaHashCompare operation
PsaAeadEncrypt
PsaAeadDecrypt
PsaRawKeyAgreement operation
ListKeys operation
ListClients operation (admin operation)
DeleteClient operation (admin operation)
Implementations
impl Opcode[src]
pub fn is_core(&self) -> bool[src]
Check if an opcode is one of a Core operation
pub fn is_admin(&self) -> bool[src]
Check if an opcode is an admin operation
pub fn is_crypto(&self) -> bool[src]
Check if an opcode is one of a PSA Crypto operation