#[repr(u16)]pub enum ResponseStatus {
Show 44 variants
Success = 0,
WrongProviderId = 1,
ContentTypeNotSupported = 2,
AcceptTypeNotSupported = 3,
WireProtocolVersionNotSupported = 4,
ProviderNotRegistered = 5,
ProviderDoesNotExist = 6,
DeserializingBodyFailed = 7,
SerializingBodyFailed = 8,
OpcodeDoesNotExist = 9,
ResponseTooLarge = 10,
AuthenticationError = 11,
AuthenticatorDoesNotExist = 12,
AuthenticatorNotRegistered = 13,
KeyInfoManagerError = 14,
ConnectionError = 15,
InvalidEncoding = 16,
InvalidHeader = 17,
WrongProviderUuid = 18,
NotAuthenticated = 19,
BodySizeExceedsLimit = 20,
AdminOperation = 21,
DeprecatedPrimitive = 22,
PsaErrorGenericError = 1_132,
PsaErrorNotSupported = 1_134,
PsaErrorNotPermitted = 1_133,
PsaErrorBufferTooSmall = 1_138,
PsaErrorAlreadyExists = 1_139,
PsaErrorDoesNotExist = 1_140,
PsaErrorBadState = 1_137,
PsaErrorInvalidArgument = 1_135,
PsaErrorInsufficientMemory = 1_141,
PsaErrorInsufficientStorage = 1_142,
PsaErrorCommunicationFailure = 1_145,
PsaErrorStorageFailure = 1_146,
PsaErrorDataCorrupt = 1_152,
PsaErrorDataInvalid = 1_153,
PsaErrorHardwareFailure = 1_147,
PsaErrorCorruptionDetected = 1_151,
PsaErrorInsufficientEntropy = 1_148,
PsaErrorInvalidSignature = 1_149,
PsaErrorInvalidPadding = 1_150,
PsaErrorInsufficientData = 1_143,
PsaErrorInvalidHandle = 1_136,
}Expand description
C-like enum mapping response status options to their code.
See the status code page for a broader description of these codes.
Variants
Success = 0
Successful operation
WrongProviderId = 1
Requested provider ID does not match that of the backend
ContentTypeNotSupported = 2
Requested content type is not supported by the backend
AcceptTypeNotSupported = 3
Requested accept type is not supported by the backend
WireProtocolVersionNotSupported = 4
Requested version is not supported by the backend
ProviderNotRegistered = 5
No provider registered for the requested provider ID
ProviderDoesNotExist = 6
No provider defined for requested provider ID
DeserializingBodyFailed = 7
Failed to deserialize the body of the message
SerializingBodyFailed = 8
Failed to serialize the body of the message
OpcodeDoesNotExist = 9
Requested operation is not defined
ResponseTooLarge = 10
Response size exceeds allowed limits
AuthenticationError = 11
Authentication failed
AuthenticatorDoesNotExist = 12
Authenticator not supported
AuthenticatorNotRegistered = 13
Authenticator not supported
KeyInfoManagerError = 14
Internal error in the Key Info Manager
ConnectionError = 15
Generic input/output error
InvalidEncoding = 16
Invalid value for this data type
InvalidHeader = 17
Constant fields in header are invalid
WrongProviderUuid = 18
The UUID vector needs to only contain 16 bytes
NotAuthenticated = 19
Request did not provide a required authentication
BodySizeExceedsLimit = 20
Request length specified in the header is above defined limit
AdminOperation = 21
The operation requires admin privilege
DeprecatedPrimitive = 22
The key template contains a deprecated type or algorithm
PsaErrorGenericError = 1_132
An error occurred that does not correspond to any defined failure cause
PsaErrorNotSupported = 1_134
The requested operation or a parameter is not supported by this implementation
PsaErrorNotPermitted = 1_133
The requested action is denied by a policy
PsaErrorBufferTooSmall = 1_138
An output buffer is too small
PsaErrorAlreadyExists = 1_139
Asking for an item that already exists
PsaErrorDoesNotExist = 1_140
Asking for an item that doesn’t exist
PsaErrorBadState = 1_137
The requested action cannot be performed in the current state
PsaErrorInvalidArgument = 1_135
The parameters passed to the function are invalid
PsaErrorInsufficientMemory = 1_141
There is not enough runtime memory
PsaErrorInsufficientStorage = 1_142
There is not enough persistent storage
PsaErrorCommunicationFailure = 1_145
There was a communication failure inside the implementation
PsaErrorStorageFailure = 1_146
There was a storage failure that may have led to data loss
PsaErrorDataCorrupt = 1_152
Stored data has been corrupted
PsaErrorDataInvalid = 1_153
Data read from storage is not valid for the implementation
PsaErrorHardwareFailure = 1_147
A hardware failure was detected
PsaErrorCorruptionDetected = 1_151
A tampering attempt was detected
PsaErrorInsufficientEntropy = 1_148
There is not enough entropy to generate random data needed for the requested action
PsaErrorInvalidSignature = 1_149
The signature, MAC or hash is incorrect
PsaErrorInvalidPadding = 1_150
The decrypted padding is incorrect
PsaErrorInsufficientData = 1_143
Insufficient data when attempting to read from a resource
PsaErrorInvalidHandle = 1_136
The key handle is not valid