Module parsec_interface::operations::ping [−][src]
Ping operation
The Ping operation is used to check if the service is alive and determine the highest wire protocol version a client can use.
The Ping operation is used to check if the service is alive and determine the highest wire protocol version a client can use.