Module parsec_interface::operations::ping [−][src]
Ping operation
The Ping operation is used to check if the service is alive and determine the highest wire protocol version a client can use.
Structs
| Operation | Native object for Ping operation. |
| Result | Native object for Ping result. |