pub trait CheckDeprecated {
// Required method
fn check_deprecated(&self) -> Result<()>;
}Expand description
Checks if any part of the key template is deprecated by PSA Crypto API
Required Methods
Sourcefn check_deprecated(&self) -> Result<()>
fn check_deprecated(&self) -> Result<()>
Return Error with status ResponseStatus::DeprecatedPrimitive if any part of the key template is deprecated by PSA Crypto API
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".